@@ -2,15 +2,15 @@ local({
   cal_params <- list(
     scale = c(1.015430, 1.017286, 1.027081),
     offset = c(0.001289063, 0.038398438, 0.013828125),
-    temperatureoffset = c(0, 0, 0),
+    temperature_offset = c(0, 0, 0),
     error = NA,
-    lightdenominator = 48,
-    lightnumerator = 911
+    light_denominator = 48,
+    light_numerator = 911
   )
 
   # Raw data from test-MPI_sample_binfile
   rawdata <- data.frame(
-    time = c(rep(1726650857, 5)),
+    TimeUTC = c(rep(1726650857, 5)),
     x = c(
       0.2421875,
       0.24609375,
@@ -32,15 +32,15 @@ local({
       -0.9531250,
       -0.9609375
     ),
-    light = c(rep(22, 5)),
-    button = c(rep(0, 5)),
-    temp = c(rep(21.3, 5)),
-    volts = c(rep(4.0896, 5))
+    Light = c(rep(22, 5)),
+    Button = c(rep(0, 5)),
+    Temp = c(rep(21.3, 5)),
+    Volts = c(rep(4.0896, 5))
   )
 
   # Expected data from read.bin()$data.out
   expected_data_G11 <- data.frame(
-    time = c(rep(1726650857, 5)),
+    TimeUTC = c(rep(1726650857, 5)),
     x = c(
       0.2472334,
       0.2511999,
@@ -62,15 +62,15 @@ local({
       -0.9647342,
       -0.9727583
     ),
-    light = c(rep(417.542, 5)),
-    button = c(rep(0, 5)),
-    temp = c(rep(21.3, 5)),
-    volts = c(rep(4.0896, 5))
+    Light = c(rep(417.542, 5)),
+    Button = c(rep(0, 5)),
+    Temp = c(rep(21.3, 5)),
+    Volts = c(rep(4.0896, 5))
   )
 
   # Expected data from read.bin()$data.out
   expected_data_G12 <- data.frame(
-    time = c(rep(1726650857, 5)),
+    TimeUTC = c(rep(1726650857, 5)),
     x = c(
       0.2472334,
       0.2511999,
@@ -92,10 +92,10 @@ local({
       -0.9647342,
       -0.9727583
     ),
-    light = c(rep(417.5417, 5)),
-    button = c(rep(0, 5)),
-    temp = c(rep(21.3, 5)),
-    volts = c(rep(4.0896, 5))
+    Light = c(rep(417.5417, 5)),
+    Button = c(rep(0, 5)),
+    Temp = c(rep(21.3, 5)),
+    Volts = c(rep(4.0896, 5))
   )
 
 
@@ -103,21 +103,21 @@ local({
   rownames(expected_data_G11) <- NULL
   rownames(expected_data_G12) <- NULL
 
-  test_that("Calibrated values are the same as GENEAread for GENEActiv 1.1 with temp TRUE.", {
+  test_that("Calibrated values are the same as GENEAread for GENEActiv 1.1 with Temp TRUE.", {
     expect_equal(apply_calibration(rawdata, cal_params, "GENEActiv 1.1"), expected_data_G11, tolerance = 1e-6)
   })
 
-  test_that("Calibrated values are the same as GENEAread for GENEActiv 1.1 with temp FALSE.", {
+  test_that("Calibrated values are the same as GENEAread for GENEActiv 1.1 with Temp FALSE.", {
     expect_equal(apply_calibration(rawdata, cal_params, "GENEActiv 1.1", FALSE), expected_data_G11, tolerance = 1e-6)
   })
 
-  test_that("Calibrated values are the same as GENEAread for GENEActiv 1.2 with temp TRUE.", {
+  test_that("Calibrated values are the same as GENEAread for GENEActiv 1.2 with Temp TRUE.", {
     expect_equal(apply_calibration(rawdata, cal_params, "GENEActiv 1.2"), expected_data_G12, tolerance = 1e-6)
   })
 
   # Test calibration against GENEAread
 
-  binfile_path <- file.path(system.file("extdata", package = "GENEAcore"), "10Hz_calibration_file.bin")
+  binfile_path <- file.path(system.file("extdata", package = "GENEAcore"), "10Hz_calibration_file_20Nov25.bin")
   output_folder <- file.path(tempdir(), "GENEAcore")
   if (!dir.exists(output_folder)) dir.create(output_folder)
 
@@ -147,8 +147,8 @@ local({
 
   library(GENEAread)
   expected_rawdata <- as.data.frame(read.bin(binfile_path)$data.out)
-  names(expected_rawdata)[c(1, 2, 3, 4, 7)] <- c("timestamp", "x", "y", "z", "temp") # Adjust column names
-  expected_rawdata$timestamp <- expected_rawdata$timestamp - 3600 # Compensate for time zone bug in GENEAread
+  names(expected_rawdata)[c(1, 2, 3, 4, 7)] <- c("TimeUTC", "x", "y", "z", "Temp") # Adjust column names
+  expected_rawdata$TimeUTC <- expected_rawdata$TimeUTC - 3600 # Compensate for TimeUTC zone bug in GENEAread
 
   # Adjust expected_rawdata for half second start
   test_that("Raw data is correct", {
